Welcome to xotless's documentation!
===================================

``xotless`` is a collection of small utilities, which we haven't had the time
to properly include in ``xotl.tools`` [#xotl-tools]_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   ranges
   types
   domains
   trees
   itertools
   pickablenv
   immutables
   walk
   context
   tracing
   testing

   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. [#xotl-tools] https://merchise-autrement.gitlab.io/xotl.tools/
